Gestion des volumes Block Storage for Classic dans IBM Cloud

Gérez les volumes d' Block Storage for Classic s via la console d' IBM Cloud, l'interface de ligne de commande (CLI), l'API ou Terraform pour configurer, surveiller et contrôler vos ressources de stockage en blocs.

Afficher les détails du volume Block Storage for Classic dans la console

Vous pouvez consulter un résumé des informations clés relatives au volume de stockage sélectionné, qui inclut les fonctionnalités de snapshot et de réplication ajoutées à ce volume.

  1. Allez sur la console IBM Cloud®. Sur le site menu Icône de menu, sélectionnez Infrastructure Icône VPC > Infrastructure classique.
  2. Cliquez sur Stockage > Block Storage for Classic. La liste des volumes de blocs s'affiche.
  3. Vous pouvez filtrer la liste en cliquant sur l' icône Filtre et en sélectionnant un lieu ou en saisissant une capacité spécifique. Cliquez sur Appliquer pour valider votre sélection.
  4. Cliquez sur le nom de volume approprié dans la liste.

Vous pouvez télécharger la liste au format CSV en cliquant sur l' icône Télécharger.

Visualiser les détails du volume Block Storage for Classic à partir de l'interface de gestion

Avant de commencer, choisissez le client d'interface de ligne de commande que vous souhaitez utiliser.

Visualisation des détails du volume Block Storage for Classic à partir de la CLI IBMCLOUD

  1. Utilisez la commande ibmcloud sl block volume-list pour afficher la liste des volumes de stockage disponibles. Localisez le volume dans la sortie. Vous pouvez trier la liste par valeurs id, username, datacenter, storage_type, capacity_gb, bytes_used, ip_addr, lunId, active_transactions, et created_by.

    • L'exemple suivant récupère la liste des volumes et les résultats trient les volumes par nom, en commençant par le volume le plus récemment créé.
      ibmcloud sl block volume-list --sortby username
      
    • L'exemple suivant permet de récupérer la liste des volumes qui ont été créés par un ordre spécifique.
      $ ibmcloud sl block volume-list --order 110758744
      id        username            datacenter   storage_type             capacity_gb   bytes_used   IOPs   ip_addr     lunId  active_transactions   rep_partner_count   notes
      562193766 SL02SEL1414935-675  dal09        endurance_block_storage  80            -            -      10.2.125.62 0      0                     0                   -
      
  2. Utilisez la commande ibmcloud sl block volume-detail pour afficher les détails d'un volume de blocs spécifique à partir de l'interface de ligne de commande.

    $ ibmcloud sl block volume-detail  562193766
    Name                       Value
    ID                         562193766
    User name                  SL02SEL1414935-675
    Type                       endurance_block_storage
    Capacity (GB)              80
    LUN Id                     0
    Endurance Tier             LOW_INTENSITY_TIER
    Endurance Tier Per IOPS    0.25
    Datacenter                 dal09
    Target IP                  10.2.125.62
    Snapshot Size (GB)         20
    Snapshot Used (Bytes)      -
    # of Active Transactions   0
    Replicant Count            0
    Notes                      -
    

Pour plus d'informations sur tous les paramètres disponibles pour ces commandes, voir ibmcloud sl block volume-detail et ibmcloud sl block volume-list.

Visualiser les détails du volume Block Storage for Classic à partir de SLCLI

Pour afficher des informations sur un volume de stockage, vous pouvez utiliser les commandes suivantes depuis l'interface CLI.

  1. Dressez la liste des volumes de stockage disponibles à l'aide de la commande slcli block volume-list et utilisez l'un des filtres disponibles pour vous aider à identifier le volume qui vous intéresse. L'exemple de commande suivant répertorie les volumes en fonction de leurs identifiants de commande.

    slcli block volume-list --order ORDER_ID
    
  2. Utilisez l'ID de volume de la sortie de la première commande pour exécuter la commande slcli block volume-detail.

    $ slcli block volume-detail --help
    Usage: slcli block volume-detail [OPTIONS] VOLUME_ID
    Options:
      -h, --help  Show this message and exit.
    

Pour plus d'informations sur tous les paramètres disponibles pour ces commandes, voir block volume-detail et block volume-list.

Mise à jour des notes d'un volume dans la console

  1. Allez sur la console IBM Cloud®. Dans le menu, sélectionnez l’icône Infrastructure VPC > Infrastructure classique.
  2. Cliquez sur Stockage > Block Storage for Classic.
  3. Recherchez le volume que vous souhaitez mettre à jour. Cliquez sur le nom du volume pour afficher la page Détails du volume.
  4. Cliquez sur l'icône Modifier l'icône à côté de Notes, et saisissez votre texte.

Mise à jour des notes d'un volume à partir de l'interface de ligne de commande (CLI)

Vous pouvez utiliser la commande ibmcloud sl call-api pour ajouter et modifier des notes pour vos volumes.

$ ibmcloud sl call-api --help
NAME:
  call-api - Call arbitrary API endpoints
USAGE:
  ibmcloud sl call-api SERVICE METHOD [OPTIONS]
OPTIONS:
  --filter value      Object filters
  -h, --help          Usage information.
  --init value        Init parameter
  --limit value       Result limit
  --mask value        Object mask: use to limit fields returned
  --offset value      Result offset
  --output value      Specify output format, only JSON is supported now.
  --parameters value  Append parameters to web call

Spécifiez l'ID du volume dans l'option --init et utilisez l'option --parameters pour définir la nouvelle note. Voir l'exemple suivant :

ibmcloud sl call-api SoftLayer_Network_Storage editObject --init 562193766 --parameters '[{"notes":"Testing."}]'

Pour plus d'informations, voir ibmcloud sl call-api.

Autorisation d'accès des hôtes à Block Storage for Classic dans la console

Les hôtes autorisés sont des hôtes auxquels l'accès à un volume particulier est accordé. Sans autorisation d'hôte, vous ne pouvez pas accéder au stockage ni l'utiliser depuis votre système. L'autorisation d'accès d'un hôte à votre volume génère le nom d'utilisateur, le mot de passe et le nom qualifié iSCSI (IQN), qui sont nécessaires pour monter la connexion iSCSI à E/S multipath (MPIO).

Vous pouvez autoriser et connecter des hôtes qui se trouvent dans le même centre de données que votre stockage. Si vous pouvez disposer de plusieurs comptes, vous ne pouvez pas autoriser un hôte à partir d'un compte à accéder à votre stockage sur un autre compte.

  1. Cliquez sur Stockage > Block Storage for Classic.
  2. Localisez le volume et cliquez sur les points de suspension icône Actions.
  3. Cliquez sur Hôte autorisé.
  4. Pour voir la liste des adresses IP ou des périphériques disponibles, indiquez tout d'abord si vous souhaitez autoriser l'accès en fonction des types de périphérique ou des sous-réseaux.
    • Si vous choisissez l'option Devices, vous pouvez opter pour des instances de serveur Bare Metal Server ou de serveur virtuel.
    • Si vous choisissez l'option adresse IP, sélectionnez le sous-réseau de votre hôte de calcul.
  5. Dans la liste filtrée, sélectionnez un ou plusieurs hôtes pouvant accéder au volume, puis cliquez sur Sauvegarder.

Le nombre d'autorisations par volume de blocs est limité par défaut à 8. Cela signifie que jusqu’à huit hôtes peuvent être autorisés à accéder au volume Block Storage for Classic. Les clients qui utilisent Block Storage for Classic dans leur déploiement VMware peuvent demander à ce que la limite d'autorisation soit augmentée jusqu'à 64. Pour demander une augmentation de la limite, générez un cas de support.

Autorisation d'accès des hôtes à Block Storage for Classic depuis l'interface de ligne de commande (CLI)

Les hôtes autorisés sont des hôtes auxquels l’accès à un volume particulier est accordé. Sans autorisation d'hôte, vous ne pouvez pas accéder au stockage ni l'utiliser depuis votre système. L'autorisation d'accès d'un hôte à votre volume génère un nom d'utilisateur et un mot de passe.

Vous pouvez autoriser et connecter des hôtes qui se trouvent dans le même centre de données que votre stockage. Si vous pouvez disposer de plusieurs comptes, vous ne pouvez pas autoriser un hôte à partir d'un compte à accéder à votre stockage sur un autre compte.

Autorisation des hôtes à partir de l'interface de ligne de commande IBMCLOUD CLI

La commande ibmcloud sl block access-authorize permet d'autoriser un hôte à accéder au volume. L'exemple suivant autorise l'instance de serveur virtuel 87654321 à monter le volume 12345678.

ibmcloud sl block access-authorize 12345678 --virtual-id 87654321

Pour plus d'informations sur tous les paramètres disponibles pour cette commande, voir ibmcloud sl block access-authorize.

Vous pouvez également spécifier un sous-réseau des instances de calcul qui sont autorisées à accéder au stockage à l'aide de la commande suivante.

ibmcloud sl block subnets-assign --subnet-id 1234 87654321

Autorisation des hôtes à partir de l'interface SLCLI

Pour autoriser un hôte à accéder au volume, vous pouvez utiliser la commande suivante.

$ slcli block access-authorize --help
Usage: slcli block access-authorize [OPTIONS] VOLUME_ID
Options:
  -h, --hardware-id TEXT    The ID of a hardware server to authorize.
  -v, --virtual-id TEXT     The ID of a virtual server to authorize.
  -i, --ip-address-id TEXT  The ID of an IP address to authorize.
  -p, --ip-address TEXT     An IP address to authorize.
  --help                    Show this message and exit.
$ slcli block subnets-list -h
Usage: slcli block subnets-list [OPTIONS] ACCESS_ID
  List block storage assigned subnets for the given host id.
  access_id is the host_id obtained by: slcli block access-list <volume_id>
Options:
    -h, --help  Show this message and exit.
$ slcli block subnets-assign -h
Usage: slcli block subnets-assign [OPTIONS] ACCESS_ID
  Assign block storage subnets to the given host id.
  access_id is the host_id obtained by: slcli block access-list <volume_id>
Options:
  --subnet-id INTEGER  ID of the subnets to assign; e.g.: --subnet-id 1234
  -h, --help           Show this message and exit.
$ slcli block subnets-remove -h
Usage: slcli block subnets-remove [OPTIONS] ACCESS_ID
  Remove block storage subnets for the given host id.
  access_id is the host_id obtained by: slcli block access-list <volume_id>
Options:
  --subnet-id INTEGER  ID of the subnets to remove; e.g.: --subnet-id 1234
  -h, --help           Show this message and exit.

Le nombre d'autorisations par volume de blocs est limité par défaut à 8. Cela signifie que jusqu’à huit hôtes peuvent être autorisés à accéder au volume Block Storage for Classic. Les clients qui utilisent Block Storage for Classic dans leur déploiement VMware peuvent demander à ce que la limite d'autorisation soit augmentée jusqu'à 64. Pour demander une augmentation de la limite, générez un cas de support.

Autorisation des hôtes à accéder à Block Storage for Classic avec Terraform

Les hôtes autorisés sont des hôtes auxquels l'accès à un volume particulier est accordé. Sans autorisation d'hôte, vous ne pouvez pas accéder au stockage ni l'utiliser depuis votre système. L'autorisation d'accès d'un hôte à votre volume génère le nom d'utilisateur, le mot de passe et le nom qualifié iSCSI (IQN), qui sont nécessaires pour monter la connexion iSCSI à E/S multipath (MPIO).

Vous pouvez autoriser et connecter des hôtes qui se trouvent dans le même centre de données que votre stockage. Si vous pouvez disposer de plusieurs comptes, vous ne pouvez pas autoriser un hôte à partir d'un compte à accéder à votre stockage sur un autre compte.

Pour autoriser un hôte de calcul à accéder au volume, utilisez la ressource ibm_storage_block et spécifiez allowed_virtual_guest_ids pour les serveurs virtuels ou allowed_hardware_ids pour les serveurs bare metal. Spécifiez allowed_ip_addresses pour définir les adresses IP qui ont accès au stockage.

L'exemple suivant définit que le serveur virtuel avec l'ID 27699397 peut accéder au volume à partir des adresses 10.40.98.193, 10.40.98.200.

resource "ibm_storage_block" "test1" {
        type = "Endurance"
        datacenter = "dal09"
        capacity = 40
        iops = 4
        os_format_type = "Linux"
        # Optional fields
        allowed_virtual_guest_ids = [ 27699397 ]
        allowed_ip_addresses = ["10.40.98.193", "10.40.98.200"]
        snapshot_capacity = 10
        hourly_billing = true
}

Pour plus d'informations sur les arguments et les attributs, voir ibm_storage_block.

Le nombre d'autorisations par volume de blocs est limité par défaut à 8. Cela signifie que jusqu’à huit hôtes peuvent être autorisés à accéder au volume Block Storage for Classic. Les clients qui utilisent Block Storage for Classic dans leur déploiement VMware peuvent demander à ce que la limite d'autorisation soit augmentée jusqu'à 64. Pour demander une augmentation de la limite, générez un cas de support.

Pour supprimer l'autorisation d'un hôte, supprimez ses détails de la ressource ibm_storage_block et appliquez vos modifications.

Affichage de la liste des hôtes autorisés à accéder à un volume Block Storage for Classic dans la console

  1. Cliquez sur Storage > Block Storage for Classic, puis cliquez sur le nom de votre volume.
  2. Cliquez sur Hôtes autorisés pour afficher la liste des instances de calcul ayant accès au volume.
  3. Cliquez sur l'icône d'actions et sélectionnez Voir les détails de l'hôte. Un panneau latéral s'affiche avec des détails tels que le nom de l'appareil, l'adresse IP, le nom d'utilisateur et le mot de passe, l'IQN de l'hôte et le type d'appareil. Lorsque l'isolation ISCSI est activée, la section Liste de contrôle d'accès s'affiche également. Vous pouvez ajouter ou supprimer des sous-réseaux dans la section Liste de contrôle d'accès.

L'adresse cible est répertoriée sur la page Détail du stockage. Pour Block Storage, il s'agit de l'adresse IP du portail Discover Target. Pour File Storage, l'adresse cible est décrite comme un nom DNS.

Mise à jour de l'autorisation de l'hôte dans la console

  1. Cliquez sur Storage > Block Storage for Classic, puis cliquez sur le nom de votre volume.
  2. Cliquez sur Hôtes autorisés pour afficher la liste des instances de calcul ayant accès au volume.
  3. Cliquez sur l'icône d'actions et sélectionnez Ajouter un sous-réseau. Cette option n'est disponible que lorsque l'isolation ISCSI est activée.
  4. Dans la nouvelle boîte de dialogue, sélectionnez le sous-réseau que vous souhaitez ajouter dans la liste.
  5. Cliquez sur Submit.

Affichage de la liste des hôtes autorisés à accéder à un volume Block Storage for Classic depuis l'interface de ligne de commande (CLI)

Affichage de la liste des hôtes autorisés à partir de l'interface de ligne de commande IBMCLOUD CLI

Pour confirmer que l'autorisation a fonctionné, exécutez la commande ibmcloud sl block access-list.

ibmcloud sl block access-list 12345678 --sortby allowed_host_id

Affichage de la liste des hôtes autorisés à partir de l'interface SLCLI

Pour consulter la liste des hôtes actuellement autorisés à accéder au volume, vous pouvez utiliser la commande suivante.

$ slcli block access-list --help
Usage: slcli block access-list [OPTIONS] VOLUME_ID
Options:
  --sortby TEXT   Column to sort by
  --columns TEXT  Columns to display. Options: id, name, type,
                  private_ip_address, source_subnet, host_iqn, username,
                  password, allowed_host_id
  -h, --help      Show this message and exit.

Affichage de la liste des hôtes autorisés à accéder à un volume Block Storage for Classic avec Terraform

Une fois votre ressource de stockage créée, vous pouvez consulter l'attribut allowed_host_info, qui contient le nom d'utilisateur, le mot de passe et l'IQN de l'hôte de calcul autorisé à accéder au volume.

Pour plus d'informations sur les arguments et les attributs, voir ibm_storage_block.

Affichage de l' Block Storage for Classic auquel un hôte est autorisé dans la console

Vous pouvez consulter les volumes auxquels un hôte a accès, y compris les informations nécessaires pour établir une connexion : nom du LUN, type de stockage, adresse cible, capacité et emplacement :

  1. Cliquez sur Devices > Device List dans la console IBM Cloud®, puis cliquez sur l'appareil concerné.
  2. Sélectionnez l'onglet Stockage.

Une liste des volumes de stockage auxquels cet hôte particulier a accès s'affiche. La liste est regroupée par type de stockage (bloc, fichier, autre). Vous pouvez autoriser davantage de stockage ou supprimer l'accès en cliquant sur Actions.

Un hôte ne peut pas être autorisé à accéder simultanément à des volumes de types de systèmes d'exploitation différents. Un hôte peut être autorisé à accéder à des volumes d'un seul type de système d'exploitation. Si vous tentez d'autoriser un hôte à accéder à plusieurs volumes dotés de systèmes d'exploitation différents, l'opération génère une erreur.

Révocation de l'accès d'un hôte à Block Storage for Classic dans la console

Si vous souhaitez ne plus autoriser un hôte à accéder à un volume de stockage en particulier, vous pouvez révoquer l'accès. Une fois l'accès révoqué, la connexion hôte est supprimée du volume. Le système d'exploitation et les applications présents sur cet hôte ne peuvent plus communiquer avec le volume.

Pour éviter tout problème côté hôte, démontez le volume de stockage de votre système d'exploitation avant de révoquer l'accès, afin d'éviter la perte de disques ou la corruption des données.

Vous pouvez révoquer l'accès à partir de la liste des périphériques ou de la vue Stockage.

Révocation de l'accès à partir de la liste des périphériques

  1. Dans la console IBM Cloud®, cliquez sur l'icône Classic Infrastructure. Cliquez ensuite sur Périphériques > Liste des périphériques, puis double-cliquez sur le périphérique souhaité.
  2. Sélectionnez l'onglet Stockage.
  3. Une liste des volumes de stockage auxquels cet hôte particulier a accès s'affiche. La liste est regroupée par type de stockage (bloc, fichier, autre). En regard du nom du volume, cliquez sur Actions, puis sur Révoquer le droit d'accès.
  4. Vérifiez que vous souhaitez bien révoquer l'accès à un volume, car cette action est irréversible. Cliquez sur Oui pour révoquer l'accès au volume ou sur Non pour annuler l'action.

Si vous souhaitez déconnecter plusieurs volumes d'un hôte spécifique, vous devez répéter l'action Révoquer le droit d'accès pour chaque volume.

Révocation de l'accès à partir de la vue Stockage

  1. Cliquez sur Stockage > Block Storage for Classic et sélectionnez le volume pour lequel vous souhaitez révoquer l'accès.
  2. Cliquez sur Hôtes autorisés.
  3. Cliquez sur l'icôneActions, puis sur Actions à côté de l'hôte dont l'accès doit être révoqué, et sélectionnez Révoquer l'accès.
  4. Vérifiez que vous souhaitez bien révoquer l'accès à un volume, car cette action est irréversible. Cliquez sur Oui pour révoquer l'accès au volume ou sur Non pour annuler l'action.

Si vous souhaitez déconnecter plusieurs hôtes d'un volume spécifique, vous devez répéter l'action Révoquer le droit d'accès pour chaque hôte.

Révocation d'un accès depuis l'interface de ligne de commande (CLI).

Si vous souhaitez ne plus autoriser un hôte à accéder à un volume de stockage en particulier, vous pouvez révoquer l'accès. Une fois l'accès révoqué, la connexion hôte est supprimée du volume. Le système d'exploitation et les applications présents sur cet hôte ne peuvent plus communiquer avec le volume.

Pour éviter tout problème côté hôte, démontez le volume de stockage de votre système d'exploitation avant de révoquer l'accès, afin d'éviter la perte de disques ou la corruption des données.

Révocation de l'accès à l'interface de ligne de commande IBMCLOUD CLI

Utilisez la commande suivante pour révoquer l'accès à partir d'un hôte de calcul. Dans l'exemple suivant, l'accès au volume 12345678 est révoqué à partir de l'instance de serveur virtuel 87654321.

ibmcloud sl block access-revoke 12345678 --virtual-id 87654321

Pour plus d'informations sur tous les paramètres disponibles pour cette commande, voir ibmcloud sl block access-revoke.

Révocation de l'accès depuis la SLCLI

Utilisez la commande suivante pour révoquer l'accès à partir d'un hôte de calcul.

$ slcli block access-revoke --help
Usage: slcli block access-revoke [OPTIONS] VOLUME_ID
Options:
  -h, --hardware-id TEXT    The ID of a hardware server to revoke authorization.
  -v, --virtual-id TEXT     The ID of a virtual server to revoke authorization.
  -i, --ip-address-id TEXT  The ID of an IP address to revoke authorization.
  -p, --ip-address TEXT     An IP address to revoke authorization.
  --help                    Show this message and exit.

Suppression d'un volume de stockage

Pour connaître la procédure à suivre afin de mettre hors service et de supprimer en toute sécurité un volume Block Storage for Classic — y compris une liste de contrôle à effectuer avant la suppression pour vous aider à éviter toute perte accidentelle de données —, consultez la section Mise hors service et suppression des volumes Block Storage for Classic.